package com.ruoyi.szxc.service.impl;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.szxc.domain.SzxcXyAuditRecard;
import com.ruoyi.szxc.mapper.SzxcXyAuditRecardMapper;
import com.ruoyi.szxc.service.ISzxcXyAuditRecardService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 审核记录Service业务层处理
 *
 * @author hs
 * @date 2024-04-15
 */
@Service
public class SzxcXyAuditRecardServiceImpl implements ISzxcXyAuditRecardService
{
    @Autowired
    private SzxcXyAuditRecardMapper szxcXyAuditRecardMapper;

    /**
     * 查询审核记录
     *
     * @param id 审核记录主键
     * @return 审核记录
     */
    @Override
    public SzxcXyAuditRecard selectSzxcXyAuditRecardById(Long id)
    {
        return szxcXyAuditRecardMapper.selectSzxcXyAuditRecardById(id);
    }

    /**
     * 查询审核记录列表
     *
     * @param szxcXyAuditRecard 审核记录
     * @return 审核记录
     */
    @Override
    public List<SzxcXyAuditRecard> selectSzxcXyAuditRecardList(SzxcXyAuditRecard szxcXyAuditRecard)
    {
        return szxcXyAuditRecardMapper.selectSzxcXyAuditRecardList(szxcXyAuditRecard);
    }

    /**
     * 新增审核记录
     *
     * @param szxcXyAuditRecard 审核记录
     * @return 结果
     */
    @Override
    public int insertSzxcXyAuditRecard(SzxcXyAuditRecard szxcXyAuditRecard)
    {
        szxcXyAuditRecard.setCreateTime(DateUtils.getNowDate());
        return szxcXyAuditRecardMapper.insertSzxcXyAuditRecard(szxcXyAuditRecard);
    }

    /**
     * 修改审核记录
     *
     * @param szxcXyAuditRecard 审核记录
     * @return 结果
     */
    @Override
    public int updateSzxcXyAuditRecard(SzxcXyAuditRecard szxcXyAuditRecard)
    {
        szxcXyAuditRecard.setUpdateTime(DateUtils.getNowDate());
        return szxcXyAuditRecardMapper.updateSzxcXyAuditRecard(szxcXyAuditRecard);
    }

    /**
     * 批量删除审核记录
     *
     * @param ids 需要删除的审核记录主键
     * @return 结果
     */
    @Override
    public int deleteSzxcXyAuditRecardByIds(Long[] ids)
    {
        return szxcXyAuditRecardMapper.deleteSzxcXyAuditRecardByIds(ids);
    }

    /**
     * 删除审核记录信息
     *
     * @param id 审核记录主键
     * @return 结果
     */
    @Override
    public int deleteSzxcXyAuditRecardById(Long id)
    {
        return szxcXyAuditRecardMapper.deleteSzxcXyAuditRecardById(id);
    }
}
